@@ -24,7 +24,7 @@ def get_cmd():
 def run(csv):
     cmd = get_cmd()
     df = pd.read_csv(csv)
-    print('csv shape: [%s rows x %s columns]' % df.shape)
+    print('\ncsv shape: [%s rows x %s columns]' % df.shape)
 
     if cmd == 's':
         split_csv(df, csv)
