@@ -11,7 +11,7 @@ def handle_col(df):
             print('列名错误，请重新输入')
 
     while True:
-        print('数值型：[1.<][2.<=][3.=][4.>][5.>=]')
+        print('\n数值型：[1.<][2.<=][3.=][4.>][5.>=]')
         print('字符串型：[6.包含][7.不包含]')
         cmd = input('请从1-7中选择一个操作：')
 
@@ -37,7 +37,7 @@ def handle_col(df):
             break
         elif cmd == '6':
             threshold = input('请输入字符：')
-            df_new = df.loc[df[col_name].str.contains(threshold)]
+            df_new = df.loc[df[col_name].str.contains(threshold) == True]
             break
         elif cmd == '7':
             threshold = input('请输入字符：')
@@ -51,8 +51,8 @@ def handle_col(df):
 def extract_csv(df, csv):
     while True:
         df = handle_col(df)
-        row = df.shape()[0]
-        print('按照条件获取了%s条数据' % row)
+        row = df.shape[0]
+        print('\n按照条件获取了%s条数据' % row)
         go_on = input('\n是否继续提取？[1.是][2.否]：')
         if go_on != '1':
             df.to_csv(csv.replace('.csv', '_extract' + '.csv'), index=False)
